import {useState, useCallback,} from 'react';

export const useRegister = () => {
    const [id, setId] = useState('');
    const [name, setName] = useState('');
    const [loading, setLoading] = useState(false);
    const [error, setError] = useState<Error | null>(null);

    // 封装为可手动触发的异步函数
    const register = useCallback(async () => {
        setLoading(true);
        setError(null);

        try {
            const response = await fetch('/api/ulocal/register', {
                method: 'POST'
            });

            if (!response.ok) {
                throw new Error(`HTTP error! status: ${response.status}`);
            }

            const data = (await response.json()).data;
            setId(data.id);
            setName(data.name);

            return {id: data.id, name: data.name};
        } catch (err) {
            setError(err instanceof Error ? err : new Error('Request failed'));
        } finally {
            setLoading(false);
        }

    }, []);

    // 如果需要自动执行（组件挂载时自动注册）
    // useEffect(() => { register() }, [register]);

    return {
        id,
        name,
        register,  // 手动触发函数
        loading,
        error
    };
};